@@ -1,7 +1,8 @@
 
-from dcop import *
+import pcop
+import dcop
 
-app = DCOPApplication( "kspread" )
+app = dcop.anyAppCalled("kspread")
 
 doc = app.default.getDocuments()[0]
 
