@@ -4,7 +4,6 @@ import org.kde.qt.*;
 
 /** {@link DeleteJob} emits these signals */
 public interface DeleteJobSignals {
-	void deleting( Job arg1, KURL file );
 
 /** 
  Emitted when the slave successfully connected to the host.
@@ -13,17 +12,20 @@ public interface DeleteJobSignals {
          
 */
 	void connected( Job arg1 );
-	void destroyed( QObject obj );
-	void totalDirs( Job arg1, long dirs );
-	void processedFiles( Job arg1, long files );
+	void processedDirs( Job arg1, long dirs );
 
 /** 
- Emitted to display information about this job, as sent by the slave.
- Examples of message are "Resolving host", "Connecting to host...", etc.
+ Emitted to display information about the speed of this job.
          
 */
-	void infoMessage( Job arg1, String msg );
-	void totalFiles( Job arg1, long files );
+	void speed( Job arg1, long bytes_per_second );
+
+/** 
+ Emitted when the job is finished, in any case (completed, canceled,
+ failed...). Use {@link DeleteJob#error} to know the result.
+         
+*/
+	void result( Job job );
 
 /** 
  Regularly emitted to show the progress of this job
@@ -31,13 +33,16 @@ public interface DeleteJobSignals {
          
 */
 	void processedSize( Job arg1, int size );
+	void totalFiles( Job arg1, long files );
 
 /** 
- Emitted when the job is finished, in any case (completed, canceled,
- failed...). Use {@link error} to know the result.
+ Emitted to display information about this job, as sent by the slave.
+ Examples of message are "Resolving host", "Connecting to host...", etc.
          
 */
-	void result( Job job );
+	void infoMessage( Job arg1, String msg );
+	void processedFiles( Job arg1, long files );
+	void destroyed( QObject obj );
 
 /** 
  Emitted when the job is canceled.
@@ -47,6 +52,18 @@ public interface DeleteJobSignals {
          
 */
 	void canceled( Job job );
+	void deleting( Job arg1, KURL file );
+	void totalDirs( Job arg1, long dirs );
+
+/** 
+ Progress signal showing the overall progress of the job
+ This is valid for any kind of job, and allows using a
+ a progress bar very easily. (see {@link KProgress}).
+ Note that this signal is not emitted for finished jobs
+ (i.e. percent is never 100).
+         
+*/
+	void percent( Job job, long percent );
 
 /** 
  Emitted when we know the size of this job (data size for transfers,
@@ -54,20 +71,5 @@ public interface DeleteJobSignals {
          
 */
 	void totalSize( Job arg1, int size );
-
-/** 
- Progress signal showing the overall progress of the job
- This is valid for any kind of job, and allows using a
- a progress bar very easily. (see {@link KProgress})
-         
-*/
-	void percent( Job job, long percent );
-	void processedDirs( Job arg1, long dirs );
-
-/** 
- Emitted to display information about the speed of this job.
-         
-*/
-	void speed( Job arg1, long bytes_per_second );
 }
 
