@@ -4,8 +4,14 @@ import org.kde.qt.*;
 
 /** {@link KAccel} emits these signals */
 public interface KAccelSignals {
-	void destroyed( QObject obj );
-	void activated( int identifier );
+	void activatedAmbiguously( int identifier );
+
+/** 
+ Emitted when one of the key codes has changed.
+	 
+*/
 	void keycodeChanged();
+	void activated( int identifier );
+	void destroyed( QObject obj );
 }
 
