@@ -4,7 +4,7 @@ import org.kde.qt.*;
 
 /** {@link KAnimWidget} emits these signals */
 public interface KAnimWidgetSignals {
-	void destroyed();
+	void destroyed( QObject obj );
 	void clicked();
 }
 
