@@ -4,13 +4,17 @@ import org.kde.qt.*;
 
 /** {@link KCharSelectTable} emits these signals */
 public interface KCharSelectTableSignals {
+	void verticalSliderPressed();
+	void horizontalSliderPressed();
 	void tableDown();
-	void destroyed( QObject obj );
 	void contentsMoving( int x, int y );
+	void focusItemChanged( char c );
+	void tableUp();
+	void destroyed( QObject obj );
+	void verticalSliderReleased();
+	void doubleClicked();
+	void horizontalSliderReleased();
 	void activated();
 	void highlighted();
-	void doubleClicked();
-	void tableUp();
-	void focusItemChanged( char c );
 }
 
