@@ -4,6 +4,6 @@ import org.kde.qt.*;
 
 /** {@link KConfig} emits these signals */
 public interface KConfigSignals {
-	void destroyed();
+	void destroyed( QObject obj );
 }
 
