@@ -5,15 +5,23 @@ import java.util.Calendar;
 
 /** {@link KDateTable} emits these signals */
 public interface KDateTableSignals {
-	void destroyed( QObject obj );
-	void contentsMoving( int x, int y );
 
-/**  The selected date changed. 
+/** 
+ The selected date changed.
+     
 */
 	void dateChanged( Calendar arg1 );
+	void verticalSliderPressed();
+	void horizontalSliderPressed();
+	void contentsMoving( int x, int y );
+	void destroyed( QObject obj );
+	void verticalSliderReleased();
 
-/**  A date has been selected by clicking on the table. 
+/** 
+ A date has been selected by clicking on the table.
+     
 */
 	void tableClicked();
+	void horizontalSliderReleased();
 }
 
