@@ -12,14 +12,19 @@ public interface KDirSizeSignals {
          
 */
 	void connected( Job arg1 );
-	void destroyed( QObject obj );
 
 /** 
- Emitted to display information about this job, as sent by the slave.
- Examples of message are "Resolving host", "Connecting to host...", etc.
+ Emitted to display information about the speed of this job.
          
 */
-	void infoMessage( Job arg1, String msg );
+	void speed( Job arg1, long bytes_per_second );
+
+/** 
+ Emitted when the job is finished, in any case (completed, canceled,
+ failed...). Use {@link KDirSize#error} to know the result.
+         
+*/
+	void result( Job job );
 
 /** 
  Regularly emitted to show the progress of this job
@@ -29,11 +34,12 @@ public interface KDirSizeSignals {
 	void processedSize( Job arg1, int size );
 
 /** 
- Emitted when the job is finished, in any case (completed, canceled,
- failed...). Use {@link error} to know the result.
+ Emitted to display information about this job, as sent by the slave.
+ Examples of message are "Resolving host", "Connecting to host...", etc.
          
 */
-	void result( Job job );
+	void infoMessage( Job arg1, String msg );
+	void destroyed( QObject obj );
 
 /** 
  Emitted when the job is canceled.
@@ -47,15 +53,11 @@ public interface KDirSizeSignals {
 /** 
  Progress signal showing the overall progress of the job
  This is valid for any kind of job, and allows using a
- a progress bar very easily. (see {@link KProgress})
+ a progress bar very easily. (see {@link KProgress}).
+ Note that this signal is not emitted for finished jobs
+ (i.e. percent is never 100).
          
 */
 	void percent( Job job, long percent );
-
-/** 
- Emitted to display information about the speed of this job.
-         
-*/
-	void speed( Job arg1, long bytes_per_second );
 }
 
