@@ -4,20 +4,34 @@ import org.kde.qt.*;
 
 /** {@link KIconView} emits these signals */
 public interface KIconViewSignals {
-	void rightButtonPressed( QIconViewItem item, QPoint pos );
-	void moved();
-	void destroyed( QObject obj );
-	void returnPressed( QIconViewItem item );
-	void rightButtonClicked( QIconViewItem item, QPoint pos );
-	void contentsMoving( int x, int y );
 	void pressed( QIconViewItem arg1, QPoint arg2 );
-	void clicked( QIconViewItem arg1, QPoint arg2 );
-	void contextMenuRequested( QIconViewItem item, QPoint pos );
+	void verticalSliderPressed();
+	void horizontalSliderPressed();
+
+/** 
+ This signal is emitted whenever the user executes an iconview item.
+ That means depending on the KDE wide Single Click/Double Click
+ setting the user clicked or double clicked on that item.
+
+ Note that you may not delete any {@link QIconViewItem} objects in slots
+ connected to this signal.
+   
+*/
+	void executed( QIconViewItem item, QPoint pos );
+	void rightButtonClicked( QIconViewItem item, QPoint pos );
+	void rightButtonPressed( QIconViewItem item, QPoint pos );
+	void onViewport();
+	void onItem( QIconViewItem item );
+	void returnPressed( QIconViewItem item );
+	void contentsMoving( int x, int y );
+//	void dropped( QDropEvent e, QIconDragItemValueList lst );
 	void currentChanged( QIconViewItem item );
 	void itemRenamed( QIconViewItem item );
-	void mouseButtonPressed( int button, QIconViewItem item, QPoint pos );
-	void mouseButtonClicked( int button, QIconViewItem item, QPoint pos );
-//	void dropped( QDropEvent e, QIconDragItemValueList lst );
+	void destroyed( QObject obj );
+	void contextMenuRequested( QIconViewItem item, QPoint pos );
+	void verticalSliderReleased();
+	void selectionChanged( QIconViewItem item );
+	void moved();
 
 /** 
  This signal gets emitted whenever the user double clicks into the
@@ -32,19 +46,9 @@ public interface KIconViewSignals {
    
 */
 	void doubleClicked( QIconViewItem item, QPoint pos );
-	void selectionChanged( QIconViewItem item );
-	void onViewport();
-	void onItem( QIconViewItem item );
-
-/** 
- This signal is emitted whenever the user executes an iconview item.
- That means depending on the KDE wide Single Click/Double Click
- setting the user clicked or double clicked on that item.
-
- Note that you may not delete any {@link QIconViewItem} objects in slots
- connected to this signal.
-   
-*/
-	void executed( QIconViewItem item, QPoint pos );
+	void horizontalSliderReleased();
+	void mouseButtonClicked( int button, QIconViewItem item, QPoint pos );
+	void mouseButtonPressed( int button, QIconViewItem item, QPoint pos );
+	void clicked( QIconViewItem arg1, QPoint arg2 );
 }
 
