@@ -6,10 +6,10 @@ import org.kde.qt.*;
 public interface KKeyChooserSignals {
 
 /** 
- Emitted when a key definition has been changed.
+ Emitted when an action's shortcut has been changed.
 
 */
 	void keyChange();
-	void destroyed();
+	void destroyed( QObject obj );
 }
 
